crates="
    public_items-v0.0.4
    public_items-v0.0.5
    public_items-v0.2.0
    public_items-v0.3.0
    public_items-v0.4.0
    thiserror-1.0.30
"
